package LATMOS::Accounts::Bases::Sql::Accreq;

use 5.010000;
use strict;
use warnings;

use LATMOS::Accounts::Utils;
use LATMOS::Accounts::Log;
use base qw(LATMOS::Accounts::Bases::Sql::objects);

our $VERSION = (q$Rev: 2008 $ =~ /^Rev: (\d+) /)[0];

=head1 NAME

LATMOS::Ad - Perl extension for blah blah blah

=head1 SYNOPSIS

  use LATMOS::Accounts::Bases;
  my $base = LATMOS::Accounts::Bases->new('sql');
  ...

=head1 DESCRIPTION

Account base access over standard unix file format.

=head1 FUNCTIONS

=cut

=head2 new(%options)

Create a new LATMOS::Ad object for windows AD $domain.

domain / server: either the Ad domain or directly the server

ldap_args is an optionnal list of arguments to pass to L<Net::LDAP>.

=cut

sub object_table { 'accreq' }

sub key_field { 'name' }

sub has_extended_attributes { 1 }

sub _get_attr_schema {
    my ($class, $base) = @_;

    $class->SUPER::_get_attr_schema($base,
        {
            exported  => { inline => 1, },
            expire    => { },
            name      => { inline => 1, ro => 1, },
            create    => { inline => 1, ro => 1, },
            date      => { inline => 1, ro => 1, },
            forward   => { },
            manager => { can_values => sub { $base->list_objects('user') } },
            department => {
                can_values => sub {
                    $base->search_objects('group', 'sutype=dpmt')
                }
            },
            contratType => {
                can_values => sub {
                    $base->search_objects('group', 'sutype=contrattype')
                }
            },
            site => {
                can_values => sub {
                    $base->search_objects('site')
                }
            },
            # Address
            co => { },
            l => { },
            postalCode => { },
            streetAddress => { },
            postOfficeBox => { },
            st => { },
            facsimileTelephoneNumber => { },
            o => { },
            telephoneNumber => { },
            physicalDeliveryOfficeName => { },
            site => {
                can_values => sub {
                    $base->search_objects('site')
                },
            },
        }
    )
}

sub _office_address_fields { qw(telephoneNumber physicalDeliveryOfficeName site) }

1;

__END__

=head1 SEE ALSO

=head1 AUTHOR

Olivier Thauvin, E<lt>olivier.thauvin@latmos.ipsl.frE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2008, 2009 CNRS SA/CETP/LATMOS

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.10.0 or,
at your option, any later version of Perl 5 you may have available.


=cut
